Credits
=======


Authors
-------

.. |orcid_jj| image:: https://img.shields.io/badge/orcid-0000----0001----7699----3983-brightgreen.svg
   :target: https://orcid.org/0000-0001-7699-3983

Starmatrix was initially developed by `Juanjo Bazán`_ |orcid_jj|

.. _`Juanjo Bazán`: https://twitter.com/xuanxu

References
----------

Starmatrix is built upon a long list of previous works from different authors/papers:

* *Ferrini et al.*,1992, ApJ, 387, 138
* *Ferrini & Poggiantti*, 1993, ApJ, 410, 44F
* *Portinari, Chiosi & Bressan.*,1998,AA,334,505P
* *Galli et al.*, 1995, ApJ, 443, 536G
* *Mollá et al*, 2015, MNRAS, 451, 3693-3708
* *Iwamoto et al*, 1999, ApJS, 125, 439
* *Matteucci & Greggio*, 1986, A&A, 154, 279M
* *Mollá et al*, 2017, MNRAS, 468, 305-318
* *Gavilan, Mollá & Buell*, 2006, A&A, 450, 509
* *Raiteri C.M., Villata M. & Navarro J.F.*, 1996, A&A 315, 105-115
* *Maoz, D. & Graur, O.* 2017, ApJ, 848, 25M
* *Castrillo, A. et al* 2020, MNRAS
* *Greggio, L.* 2005, A&A 441, 1055–1078

License
-------

*Copyright* © 2019-2020 Juanjo Bazán, released under the `MIT license`_.

.. _`MIT license`: https://github.com/xuanxu/starmatrix/blob/master/LICENSE

